@@ -6,7 +6,7 @@ user_id = os.environ['USER_ID']
 token = os.environ['API_TOKEN']
 url_api = os.environ['API_ROOT']
 url_endpoint = url_api + "/user/projects/task/verify"
-
+print(url_endpoint)
 headers = {'x-api-key': f"{token}"}
 
 def get_errors_fails(report_path: str):
@@ -43,9 +43,15 @@ def mark_complete(task_id: str, message=None):
             }
     if message:
         data['message'] = message
-
-    r = requests.post(url_endpoint, headers=headers, data=json.dumps(data))
-    assert r.status_code == 200
+    
+    try:
+        r = requests.post(url_endpoint, headers=headers, data=json.dumps(data))
+        print(f'Marking task {task_id} as complete for user {user_id}')
+        print(r.text)
+        assert r.status_code == 200
+    except Exception as e:
+        print(f'Error marking task {task_id} as complete for user {user_id}')
+        
 
 def mark_incomplete(task_id: str, message=None):
     data = {
@@ -55,7 +61,11 @@ def mark_incomplete(task_id: str, message=None):
             }
     if message:
         data['message'] = message
+    try:
+        r = requests.post(url_endpoint, headers=headers, data=json.dumps(data))
+        print(f'Marking task {task_id} as incomplete for user {user_id}')
+        print(r.text)
+        assert r.status_code == 200
+    except:
+        print(f'Error marking task {task_id} as incomplete for user {user_id}')
 
-    r = requests.post(url_endpoint, headers=headers, data=json.dumps(data))
-    
-    assert r.status_code == 200
